@@ -129,7 +129,7 @@
 $I:.:+I=................ .......... ........................................=:
  :8=+.,?$:.......................................  .... .............    ..,,= .
 """
-__version__ = '2.0.5'
+__version__ = '2.1.0'
 
 # Add NullHandler to prevent logging warnings
 import logging
@@ -141,7 +141,7 @@ except ImportError:
         def emit(self, record):
             pass
 
-logging.getLogger('helper').addHandler(NullHandler())
+logging.getLogger().addHandler(NullHandler())
 
 # Import the Controller for extending
 from helper.controller import Controller
